.. _loading_and_updating_data:

Loading and updating data
=========================

The primary means of managing Disease Normalizer data is via the included command-line interface.

.. note::

    See the :ref:`ETL API documentation<etl-api>` for information on programmatic access to the data loader classes.

.. click:: disease.cli:cli
   :prog: disease-normalizer
   :nested: full
